package com.example.johannes.bluetoothtestapp;

import android.bluetooth.BluetoothAdapter;
import android.bluetooth.BluetoothDevice;
import android.content.BroadcastReceiver;
import android.content.Context;
import android.content.Intent;
import android.content.IntentFilter;
import android.graphics.Color;
import android.os.Handler;
import android.os.Message;
import android.support.v7.app.ActionBarActivity;
import android.os.Bundle;
import android.util.Log;
import android.view.Menu;
import android.view.MenuItem;
import android.view.MotionEvent;
import android.view.View;
import android.widget.Button;
import android.widget.EditText;
import android.widget.TextView;
import android.widget.Toast;


public class MainActivity extends ActionBarActivity {

    private static final int PREFERENCE_MODE_PRIVATE = 0;
    private static final int REQUEST_ENABLE_BT = 1;
    private static final String BT_NAME_SERVER = "Serial Adaptor"; //NAME VON BLUETOOTHMODUL!

    private Button connect, send, stop_con, clear;
    private EditText text1;
    private TextView receive_text;

    private connection_bt con1;

    private BluetoothAdapter bluetooth = BluetoothAdapter.getDefaultAdapter();

    private Handler myHandler = new Handler() {
        @Override
        public void handleMessage (Message msg) {
            String message = receive_text.getText().toString();
            if (message.equals(getString(R.string.receive))) message = "";
            message = message + (String) msg.obj + " ";

            receive_text.setText(message);
        }
    };

    private final BroadcastReceiver Empfaenger = new BroadcastReceiver() {
        public void onReceive(Context context, Intent intent) {
            String action = intent.getAction();
            if (BluetoothDevice.ACTION_FOUND.equals(action)) {
                BluetoothDevice dev = intent.getParcelableExtra(BluetoothDevice.EXTRA_DEVICE);
                Log.e("Geräte-Name:", dev.getName());
                if (dev.getName().equals(BT_NAME_SERVER)) {
                    Log.e("Verbindung mit ", dev.getName() + " aufbauen");

                    bluetooth.cancelDiscovery();

                    con1 = new connection_bt(dev, myHandler);
                    con1.start();
                    if (con1 != null) {
                        connect.setEnabled(false);
                        connect.setBackgroundColor(Color.GREEN);
                    }
                }
            }
        }
    };

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);
        setContentView(R.layout.activity_main);

        Initializiation();

        connect.setOnTouchListener(new View.OnTouchListener() {
            @Override
            public boolean onTouch(View v, MotionEvent event) {
                connect.setBackgroundColor(Color.YELLOW);
                if (bluetooth == null) {
                    connect.setEnabled(true);
                    Toast.makeText(getApplicationContext(), "Ihr Handy unterstützt kein Bluetooth...", Toast.LENGTH_SHORT).show();
                }
                if (!bluetooth.isEnabled()) {
                    Intent blue_on = new Intent(BluetoothAdapter.ACTION_REQUEST_ENABLE);
                    startActivityForResult(blue_on, REQUEST_ENABLE_BT);
                } else bluetooth.startDiscovery();

                IntentFilter filter_get = new IntentFilter(BluetoothDevice.ACTION_FOUND);
                registerReceiver(Empfaenger, filter_get);

                return true;
            }
        });

        clear.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                receive_text.setText("");
            }
        });

        send.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                if (con1 != null) {
                    con1.write(text1.getText().toString());
                } else Toast.makeText(getApplicationContext(), "Verbindung muss hergestellt werden", Toast.LENGTH_SHORT).show();
            }
        });

        stop_con.setOnClickListener(new View.OnClickListener() {
            @Override
            public void onClick(View v) {
                try {
                    con1.stop_connection();
                    con1.isInterrupted();
                    connect.setEnabled(true);
                    connect.setBackgroundColor(Color.RED);
                } catch (Exception e) {
                    Log.e("Fehler beim Abbauen der Verbindung:", "",e);
                }
            }
        });
    }

    @Override
    public boolean onCreateOptionsMenu(Menu menu) {
        // Inflate the menu; this adds items to the action bar if it is present.
        getMenuInflater().inflate(R.menu.menu_main, menu);
        return true;
    }

    @Override
    public boolean onOptionsItemSelected(MenuItem item) {
        // Handle action bar item clicks here. The action bar will
        // automatically handle clicks on the Home/Up button, so long
        // as you specify a parent activity in AndroidManifest.xml.
        int id = item.getItemId();

        //noinspection SimplifiableIfStatement
        if (id == R.id.action_settings) {
            return true;
        }

        return super.onOptionsItemSelected(item);
    }

    public void onActivityResult(int requestCode, int resultCode, Intent data) {
        if (requestCode==REQUEST_ENABLE_BT) {
            if (resultCode==RESULT_OK) {
                Toast.makeText(getApplicationContext(), "Bluetooth erfolgreich aktiviert...", Toast.LENGTH_SHORT).show();
                bluetooth.startDiscovery();
            } else if (resultCode==RESULT_CANCELED) {
                Toast.makeText(getApplicationContext(), "Bluetooth konnte nicht aktiviert werden...", Toast.LENGTH_SHORT).show();
            }
        }
    }

    void Initializiation() {
        connect = (Button)findViewById(R.id.connection);
        connect.setBackgroundColor(Color.RED);
        stop_con = (Button)findViewById(R.id.stop_con);
        clear = (Button)findViewById(R.id.clear);
        send = (Button)findViewById(R.id.send);
        text1 = (EditText)findViewById(R.id.text1);
        receive_text = (TextView)findViewById(R.id.receive_text);
    }

    @Override
    public void onDestroy() {
        unregisterReceiver(Empfaenger);
    }
}
